@@ -1,6 +1,8 @@
 // Copyright (c) 1994, 1995, 1996 James Clark
 // See the file COPYING for copying permission.
 
+// $XFree86: doctools/jade/include/config.h,v 1.5 2005/06/06 15:22:27 tsi Exp $
+
 #ifndef config_INCLUDED
 #define config_INCLUDED 1
 
@@ -34,6 +36,10 @@
 #define SP_ANSI_LIB
 #define SP_NO_STD_NAMESPACE
 #undef SP_NEW_H_MISSING
+#if __GNUC__ > 2
+#define SP_HAVE_TYPENAME
+#undef SP_NO_STD_NAMESPACE
+#endif
 #endif
 
 #endif /* __GNUG__ */
